@@ -121,7 +121,9 @@ check_entries <- function(dict) {
 #'                           taxation = "taxation",
 #'                           taxregex = "tax*",
 #'                           country = "america"))
-#' head(dfm(tokens(corp), dictionary = dict))
+#' tokens(corp) |>
+#'     tokens_lookup(dictionary = dict) |>
+#'     dfm()
 #'
 #' # subset a dictionary
 #' dict[1:2]
@@ -132,18 +134,20 @@ check_entries <- function(dict) {
 #' c(dict["christmas"], dict["country"])
 #'
 #' \dontrun{
+#' dfmat <- dfm(tokens(data_corpus_inaugural))
+#' 
 #' # import the Laver-Garry dictionary from Provalis Research
 #' dictfile <- tempfile()
 #' download.file("https://provalisresearch.com/Download/LaverGarry.zip",
 #'               dictfile, mode = "wb")
 #' unzip(dictfile, exdir = (td <- tempdir()))
 #' dictlg <- dictionary(file = paste(td, "LaverGarry.cat", sep = "/"))
-#' head(dfm(data_corpus_inaugural, dictionary = dictlg))
+#' dfm_lookup(dfmat, dictlg)
 #'
 #' # import a LIWC formatted dictionary from http://www.moralfoundations.org
 #' download.file("http://bit.ly/37cV95h", tf <- tempfile())
 #' dictliwc <- dictionary(file = tf, format = "LIWC")
-#' head(dfm(data_corpus_inaugural, dictionary = dictliwc))
+#' dfm_lookup(dfmat, dictliwc)
 #' }
 #' @export
 dictionary <- function(x, file = NULL, format = NULL,
@@ -231,7 +235,6 @@ dictionary.dictionary2 <- function(x, file = NULL, format = NULL,
 
 # coercion and checking methods -----------
 
-#' @param object the dictionary to be coerced
 #' @param flatten flatten the nested structure if `TRUE`
 #' @param levels integer vector indicating levels in the dictionary. Used only
 #'   when `flatten = TRUE`.
@@ -255,11 +258,8 @@ setMethod("as.list",
 #'
 #' Convert a dictionary from a different format into a \pkg{quanteda}
 #' dictionary, or check to see if an object is a dictionary.
-#' @param x a dictionary-like object to be coerced or checked
-#' @param format input format for the object to be coerced to a
-#'   [dictionary]; current legal values are a data.frame with the fields
-#'   `word` and `sentiment` (as per the **tidytext** package)
-#' @inheritParams dictionary
+#' @param x a object to be coerced to a [dictionary] object.
+#' @param ... additional arguments passed to underlying functions.
 #' @return `as.dictionary` returns a \pkg{quanteda} [dictionary]
 #'   object.  This conversion function differs from the [dictionary()]
 #'   constructor function in that it converts an existing object rather than
@@ -288,15 +288,10 @@ setMethod("as.list",
 #' as.dictionary(dat, tolower = FALSE)
 #' }
 #'
-as.dictionary <- function(x, format = c("tidytext"), separator = " ", tolower = FALSE) {
+as.dictionary <- function(x, ...) {
     UseMethod("as.dictionary")
 }
 
-#' @export
-as.dictionary.default <- function(x, format = c("tidytext"), separator = " ", tolower = FALSE) {
-    check_class(class(x), "as.dictionary")
-}
-
 #' @export
 #' @noRd
 #' @method as.dictionary dictionary2
@@ -305,14 +300,25 @@ as.dictionary.dictionary2 <- function(x, ...) {
     upgrade_dictionary2(x)
 }
 
-#' @noRd
+#' @method as.dictionary list
+#' @export
+as.dictionary.list <- function(x, separator = " ", tolower = TRUE, ...) {
+    check_dots(...)
+    dictionary(x, separator = separator, tolower = tolower)
+}
+
+#' @rdname as.dictionary
+#' @param format input format for the object to be coerced to a
+#'   [dictionary]; current legal values are a data.frame with the fields
+#'   `word` and `sentiment` (as per the **tidytext** package)
+#' @inheritParams dictionary
 #' @method as.dictionary data.frame
 #' @export
-as.dictionary.data.frame <- function(x, format = c("tidytext"), separator = " ", tolower = FALSE) {
+as.dictionary.data.frame <- function(x, format = c("tidytext"), 
+                                     separator = " ", tolower = FALSE, ...) {
     
+    check_dots(...)
     format <- match.arg(format)
-    separator <- check_character(separator)
-    tolower <- check_logical(tolower)
 
     if (format == "tidytext") {
         if (!all(c("word", "sentiment") %in% names(x)))
@@ -410,7 +416,6 @@ print_dictionary <- function(entry, level = 1,
     }
 }
 
-#' @param object the dictionary to be extracted
 #' @param i index for entries
 #' @rdname dictionary-class
 #' @export
@@ -429,7 +434,6 @@ setMethod("[",
               result
           })
 
-#' @param object the dictionary to be extracted
 #' @param i index for entries
 #' @rdname dictionary-class
 #' @export
