@@ -1,6 +1,6 @@
 #include "lib.h"
 using namespace quanteda;
-using namespace arma;
+//using namespace arma;
 
 /* 
  * This function removes a string from of a list of string vectors.
