@@ -50,11 +50,16 @@ test_that("dictionary constructor works with LIWC format", {
                                       ANOTHER_CATEGORY = c("had", "mary"))))
 })
 
-test_that("dictionary constructor works with Lexicoder format", {
+test_that("dictionary constructor works with Yoshicoder format", {
     expect_equivalent(dictionary(file = "../data/dictionaries/mary.lcd"),
                       marydict)
 })
 
+test_that("dictionary constructor works with Lexicoder format", {
+    expect_equivalent(dictionary(file = "../data/dictionaries/mary.lc3"),
+                      marydict)
+})
+
 test_that("read a dictionary with NA as a key", {
     testdict <- dictionary(file = "../data/dictionaries/issue-459.cat")
     expect_true("NA" %in% names(testdict$SOUTH))
